@@ -80,7 +80,7 @@ if TYPE_CHECKING:
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020-2022 Dominic Davis-Foster"
 __license__: str = "BSD 3-Clause License"
-__version__: str = "1.1.0"
+__version__: str = "1.1.2"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["URL", "URLPath", "Domain", "URLType", "URLPathType"]
@@ -117,21 +117,24 @@ class URLPath(pathlib.PurePosixPath):
 		Return the string representation of the path, suitable for passing to system calls.
 		"""
 
+		if not hasattr(self, "_root"):
+			self._load_parts()  # type: ignore[attr-defined]
+
 		try:
 			return self._str  # type: ignore
 		except AttributeError:
 			self._str = self._format_parsed_parts(self._drv, self._root, self._parts) or ''  # type: ignore
 			return self._str
 
-	def __repr__(self):
+	def __repr__(self) -> str:
 		return super().__repr__()
 
 	@classmethod
 	def _format_parsed_parts(cls, drv, root, parts):
 		if drv or root:
-			return drv + root + pathlib._posix_flavour.join(parts[1:])  # type: ignore
+			return drv + root + '/'.join(parts[1:])
 		else:
-			return pathlib._posix_flavour.join(parts)  # type: ignore
+			return '/'.join(parts)
 
 	def is_absolute(self) -> bool:
 		"""
